@@ -195,7 +195,7 @@ def iter_last(values: Iterable[T]) -> Iterable[Tuple[bool, T]]:
     markdown_example = """\
 # Markdown
 
-Supports much of the *markdown*, __syntax__!
+Supports much of the *markdown* __syntax__!
 
 - Headers
 - Basic formatting: **bold**, *italic*, `code`
@@ -231,8 +231,8 @@ if __name__ == "__main__":  # pragma: no cover
 
     text = console.file.getvalue()
     # https://bugs.python.org/issue37871
-    for line in text.splitlines():
-        print(line)
+    for line in text.splitlines(True):
+        print(line, end="")
 
     print(f"rendered in {taken}ms")
 
