@@ -1,8 +1,10 @@
 import builtins
 import os
+from rich.repr import RichReprResult
 import sys
 from array import array
 from collections import Counter, defaultdict, deque, UserDict, UserList
+import dataclasses
 from dataclasses import dataclass, fields, is_dataclass
 from inspect import isclass
 from itertools import islice
@@ -28,16 +30,6 @@ except ImportError:  # pragma: no cover
     _attr_module = None  # type: ignore
 
 
-def _is_attr_object(obj: Any) -> bool:
-    """Check if an object was created with attrs module."""
-    return _attr_module is not None and _attr_module.has(type(obj))
-
-
-def _get_attr_fields(obj: Any) -> Iterable["_attr_module.Attribute[Any]"]:
-    """Get fields for an attrs object."""
-    return _attr_module.fields(type(obj)) if _attr_module is not None else []
-
-
 from .highlighter import ReprHighlighter
 from . import get_console
 from ._loop import loop_last
@@ -63,6 +55,33 @@ if TYPE_CHECKING:
 _re_jupyter_repr = re.compile(f"^_repr_.+_$")
 
 
+def _is_attr_object(obj: Any) -> bool:
+    """Check if an object was created with attrs module."""
+    return _attr_module is not None and _attr_module.has(type(obj))
+
+
+def _get_attr_fields(obj: Any) -> Iterable["_attr_module.Attribute[Any]"]:
+    """Get fields for an attrs object."""
+    return _attr_module.fields(type(obj)) if _attr_module is not None else []
+
+
+def _is_dataclass_repr(obj: object) -> bool:
+    """Check if an instance of a dataclass contains the default repr.
+
+    Args:
+        obj (object): A dataclass instance.
+
+    Returns:
+        bool: True if the default repr is used, False if there is a custom repr.
+    """
+    # Digging in to a lot of internals here
+    # Catching all exceptions in case something is missing on a non CPython implementation
+    try:
+        return obj.__repr__.__code__.co_filename == dataclasses.__file__
+    except Exception:
+        return False
+
+
 def install(
     console: Optional["Console"] = None,
     overflow: "OverflowMethod" = "ignore",
@@ -82,7 +101,8 @@ def install(
         max_length (int, optional): Maximum length of containers before abbreviating, or None for no abbreviation.
             Defaults to None.
         max_string (int, optional): Maximum length of string before truncating, or None to disable. Defaults to None.
-        expand_all (bool, optional): Expand all containers. Defaults to False
+        expand_all (bool, optional): Expand all containers. Defaults to False.
+        max_frames (int): Maximum number of frames to show in a traceback, 0 for no maximum. Defaults to 100.
     """
     from rich import get_console
 
@@ -146,9 +166,17 @@ def install(
         ip = get_ipython()  # type: ignore
         from IPython.core.formatters import BaseFormatter
 
+        class RichFormatter(BaseFormatter):  # type: ignore
+            pprint: bool = True
+
+            def __call__(self, value: Any) -> Any:
+                if self.pprint:
+                    return ipy_display_hook(value)
+                else:
+                    return repr(value)
+
         # replace plain text formatter with rich formatter
-        rich_formatter = BaseFormatter()
-        rich_formatter.for_type(object, func=ipy_display_hook)
+        rich_formatter = RichFormatter()
         ip.display_formatter.formatters["text/plain"] = rich_formatter
     except Exception:
         sys.displayhook = display_hook
@@ -192,8 +220,8 @@ class Pretty(JupyterMixin):
         self._object = _object
         self.highlighter = highlighter or ReprHighlighter()
         self.indent_size = indent_size
-        self.justify = justify
-        self.overflow = overflow
+        self.justify: Optional["JustifyMethod"] = justify
+        self.overflow: Optional["OverflowMethod"] = overflow
         self.no_wrap = no_wrap
         self.indent_guides = indent_guides
         self.max_length = max_length
@@ -503,9 +531,24 @@ def traverse(
                 else:
                     yield arg
 
-        if hasattr(obj, "__rich_repr__") and not isclass(obj):
+        try:
+            fake_attributes = hasattr(
+                obj, "awehoi234_wdfjwljet234_234wdfoijsdfmmnxpi492"
+            )
+        except Exception:
+            fake_attributes = False
+
+        rich_repr_result: Optional[RichReprResult] = None
+        if not fake_attributes:
+            try:
+                if hasattr(obj, "__rich_repr__") and not isclass(obj):
+                    rich_repr_result = obj.__rich_repr__()
+            except Exception:
+                pass
+
+        if rich_repr_result is not None:
             angular = getattr(obj.__rich_repr__, "angular", False)
-            args = list(iter_rich_args(obj.__rich_repr__()))
+            args = list(iter_rich_args(rich_repr_result))
             class_name = obj.__class__.__name__
 
             if args:
@@ -544,7 +587,7 @@ def traverse(
                     children=[],
                     last=root,
                 )
-        elif _is_attr_object(obj):
+        elif _is_attr_object(obj) and not fake_attributes:
             children = []
             append = children.append
 
@@ -592,9 +635,8 @@ def traverse(
         elif (
             is_dataclass(obj)
             and not isinstance(obj, type)
-            and (
-                "__create_fn__" in obj.__repr__.__qualname__ or py_version == (3, 6)
-            )  # Check if __repr__ wasn't overridden
+            and not fake_attributes
+            and (_is_dataclass_repr(obj) or py_version == (3, 6))
         ):
             obj_id = id(obj)
             if obj_id in visited_ids:
@@ -611,13 +653,12 @@ def traverse(
                 last=root,
             )
 
-            for last, field in loop_last(fields(obj)):
-                if field.repr:
-                    child_node = _traverse(getattr(obj, field.name))
-                    child_node.key_repr = field.name
-                    child_node.last = last
-                    child_node.key_separator = "="
-                    append(child_node)
+            for last, field in loop_last(field for field in fields(obj) if field.repr):
+                child_node = _traverse(getattr(obj, field.name))
+                child_node.key_repr = field.name
+                child_node.last = last
+                child_node.key_separator = "="
+                append(child_node)
 
             pop_visited(obj_id)
 
